import requests
import json
import pandas as pd

class World2Vec:
    def __init__(self, API_KEY):
        self.API_URL = 'https://api.world2vec.com'
        self.API_KEY = API_KEY

    def get_by_id(self, ids, start=None, end=None):
        params = {
            'series': ids,
            'api_key': self.API_KEY,
            'type': 'dataframe-skinny'
        }
        if start:
            params['start'] = start
        if end:
            params['end'] = end
        response = requests.post(f'{self.API_URL}/numbers', json=params)
        loaded = json.loads(response.content)
        df = pd.DataFrame(loaded['data'], columns=loaded['columns'])
        df['time'] = df['time'].astype('datetime64[ms]')
        return df
  
    def get_by_query(self, query, start=None, end=None):
        time_params = '&start=' + start if start else '' + '&end=' + end if end else ''
        url = f'{self.API_URL}/numbers/query/${query}?type=dataframe-skinny'
        if len(time_params) > 0:
            url += time_params
        response = requests.get(url)
        loaded = json.loads(response.content)
        df = pd.DataFrame(loaded['data'], columns=loaded['columns'])
        df['time'] = df['time'].astype('datetime64[ms]')
        return df



import pathlib
from setuptools import setup

# The directory containing this file
HERE = pathlib.Path(__file__).parent

# The text of the README file
README = (HERE / "README.md").read_text()

# This call to setup() does all the work
setup(
    name="world2vec",
    version="0.3.0",
    description="The python API client for world2vec",
    long_description=README,
    long_description_content_type="text/markdown",
    author="world2vec",
    author_email="nathan@world2vec.com",
    license="MIT",
    packages=["world2vec"],
    include_package_data=True,
    install_requires=["pandas"],
      classifiers=[
            'Development Status :: 3 - Alpha',      
            'Intended Audience :: Developers',      
            'Topic :: Software Development :: Build Tools',
            'License :: OSI Approved :: MIT License',   
            'Programming Language :: Python :: 3',      
            'Programming Language :: Python :: 3.7',
  ],
    entry_points={
        "console_scripts": [
            "world2vec=world2vec.__main__:main",
        ]
    },
)